@@ -27,7 +27,6 @@
 # include "config.h"
 #endif
 
-#include <unistd.h>
 #include <stdlib.h>
 #include <limits.h>
 #include <stdio.h>
@@ -36,16 +35,13 @@
 #include <ctype.h>
 #include <errno.h>
 
-#if (SIZEOF_LONG_LONG * CHAR_BIT) < 64
-# error "long long has fewer than 64 bits"
-#endif
-
 #include "gettext.h"
 #define _(string) gettext(string)
 
 #include "list.h"
 #include "smtp.h"
 #include "tools.h"
+#include "net.h"
 #include "xalloc.h"
 #include "conf.h"
 
